![CI](https://github.com/krcb197/PeakRDL-python/actions/workflows/action.yaml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/peakrdl-python/badge/?version=latest)](https://peakrdl-python.readthedocs.io/en/latest/?badge=latest)

# PeakRDL-python
Generate Python wrapper for a register model compiled SystemRDL input

## Documentation
See the [PeakRDL Python Documentation](https://peakrdl-python.readthedocs.io/) for more details


